@@ -2,7 +2,7 @@
 import sys
 
 
-__version__ = '5.4.0'
+__version__ = '6.0.0'
 
 API_PATH = {
     'about_edited':           'r/{subreddit}/about/edited/',
@@ -135,6 +135,7 @@ API_PATH = {
     'site_admin':             'api/site_admin/',
     'spoiler':                'api/spoiler/',
     'sticky_submission':      'api/set_subreddit_sticky/',
+    'store_visits':           'api/store_visits',
     'sub_recommended':        'api/recommend/sr/{subreddits}',
     'submission':             'comments/{id}/',
     'submission_replies':     'message/selfreply/',
@@ -171,6 +172,11 @@ API_PATH = {
     'user':                   'user/{user}/',
     'user_about':             'user/{user}/about/',
     'vote':                   'api/vote/',
+    'widget_create':          'r/{subreddit}/api/widget',
+    'widget_lease':           'r/{subreddit}/api/widget_image_upload_s3',
+    'widget_modify':          'r/{subreddit}/api/widget/{widget_id}',
+    'widget_order':           'r/{subreddit}/api/widget_order/{section}',
+    'widgets':                'r/{subreddit}/api/widgets',
     'wiki_edit':              'r/{subreddit}/api/wiki/edit/',
     'wiki_page':              'r/{subreddit}/wiki/{page}',
     'wiki_page_editor':       'r/{subreddit}/api/wiki/alloweditor/{method}',
