@@ -1,5 +1,4 @@
 """Provide the Comment class."""
-from ...const import urljoin
 from ...exceptions import ClientException
 from ..comment_forest import CommentForest
 from .base import RedditBase
@@ -14,6 +13,19 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
                                'comment tree')
     STR_FIELD = 'id'
 
+    @staticmethod
+    def id_from_url(url):
+        """Get the ID of a comment from the full URL."""
+        parts = RedditBase._url_parts(url)
+        try:
+            comment_index = parts.index('comments')
+        except ValueError:
+            raise ClientException('Invalid URL: {}'.format(url))
+
+        if len(parts) - 4 != comment_index:
+            raise ClientException('Invalid URL: {}'.format(url))
+        return parts[-1]
+
     @property
     def is_root(self):
         """Return True when the comment is a top level comment."""
@@ -29,7 +41,12 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
 
     @property
     def replies(self):
-        """Provide an instance of :class:`.CommentForest`."""
+        """Provide an instance of :class:`.CommentForest`.
+
+        This property may return an empty list if the comment
+        has not been refreshed with :meth:`.refresh()`
+
+        """
         if isinstance(self._replies, list):
             self._replies = CommentForest(self.submission, self._replies)
         return self._replies
@@ -52,14 +69,17 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
             reply.submission = submission
 
     def __init__(self, reddit, id=None,  # pylint: disable=redefined-builtin
-                 _data=None):
+                 url=None, _data=None):
         """Construct an instance of the Comment object."""
-        if bool(id) == bool(_data):
-            raise TypeError('Either `id` or `_data` must be provided.')
+        if [id, url, _data].count(None) != 2:
+            raise TypeError('Exactly one of `id`, `url`, or `_data` must be '
+                            'provided.')
         self._mod = self._replies = self._submission = None
         super(Comment, self).__init__(reddit, _data)
         if id:
             self.id = id  # pylint: disable=invalid-name
+        elif url:
+            self.id = self.id_from_url(url)
         else:
             self._fetched = True
 
@@ -129,7 +149,7 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
            print('Top-most Ancestor: {}'.format(ancestor))
 
         The above code should result in 5 network requests to Reddit. Without
-        the calls to :meth:`.refresh` it would make at least 31 network
+        the calls to :meth:`.refresh()` it would make at least 31 network
         requests.
 
         """
@@ -146,33 +166,19 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
         parent._submission = self.submission
         return parent
 
-    def permalink(self, fast=False):
-        """Return a permalink to the comment.
-
-        :param fast: Return the result as quickly as possible (default: False).
-
-        In order to determine the full permalink for a comment, the Submission
-        may need to be fetched if it hasn't been already. Set ``fast=True`` if
-        you want to bypass that possible load.
-
-        A full permalink looks like:
-        /r/redditdev/comments/2gmzqe/praw_https_enabled/cklhv0f
-
-        A fast-loaded permalink for the same comment will look like:
-        /comments/2gmzqe//cklhv0f
-
-        """
-        # pylint: disable=no-member
-        if not fast or 'permalink' in self.submission.__dict__:
-            return urljoin(self.submission.permalink, self.id)
-        return '/comments/{}//{}'.format(self.submission.id, self.id)
-
     def refresh(self):
         """Refresh the comment's attributes.
 
         If using :meth:`.Reddit.comment` this method must be called in order to
         obtain the comment's replies.
 
+        Example usage:
+
+        .. code:: python
+
+           comment = reddit.comment('dkk4qjd')
+           comment.refresh()
+
         """
         if 'context' in self.__dict__:  # Using hasattr triggers a fetch
             comment_path = self.context.split('?', 1)[0]
@@ -208,7 +214,16 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
 
 
 class CommentModeration(ThingModerationMixin):
-    """Provide a set of functions pertaining to Comment moderation."""
+    """Provide a set of functions pertaining to Comment moderation.
+
+    Example usage:
+
+    .. code:: python
+
+       comment = reddit.comment('dkk4qjd')
+       comment.mod.approve()
+
+    """
 
     def __init__(self, comment):
         """Create a CommentModeration instance.
