@@ -1,7 +1,6 @@
 """Provide the Subreddit class."""
 from copy import deepcopy
 from json import dumps
-import time
 
 from prawcore import Redirect
 
@@ -11,8 +10,10 @@ from ..util import permissions_string, stream_generator
 from ..listing.generator import ListingGenerator
 from ..listing.mixins import SubredditListingMixin
 from .base import RedditBase
+from .emoji import SubredditEmoji
 from .mixins import MessageableMixin
 from .modmail import ModmailConversation
+from .widgets import SubredditWidgets
 from .wikipage import WikiPage
 
 
@@ -41,13 +42,43 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
        for submission in reddit.subreddit('redditdev+learnpython').top('all'):
            print(submission)
 
-    Subreddits can be filtered from combined listings as follows:
+    Subreddits can be filtered from combined listings as follows. Note that
+    these filters are ignored by certain methods, including
+    :attr:`~praw.models.Subreddit.comments`,
+    :meth:`~praw.models.Subreddit.gilded`, and
+    :meth:`.SubredditStream.comments`.
 
     .. code:: python
 
        for submission in reddit.subreddit('all-redditdev').new():
            print(submission)
 
+    **Typical Attributes**
+
+    This table describes attributes that typically belong to objects of this
+    class. Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a
+    guarantee that these attributes will always be present, nor is this list
+    comprehensive in any way.
+
+    ======================= ===================================================
+    Attribute               Description
+    ======================= ===================================================
+    ``created_utc``         Time the subreddit was created, represented in
+                            `Unix Time`_.
+    ``description``         Subreddit description, in Markdown.
+    ``description_html``    Subreddit description, in HTML.
+    ``display_name``        Name of the subreddit.
+    ``over18``              Whether or not the subreddit is NSFW.
+    ``public_description``  Description of the subreddit, shown in searches
+                            and on the "You must be invited to visit this
+                            community" page (if applicable).
+    ``subscribers``         Count of subscribers to the subreddit.
+    ======================= ===================================================
+
+
+    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+
     """
 
     # pylint: disable=too-many-public-methods
@@ -56,7 +87,8 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
     MESSAGE_PREFIX = '#'
 
     @staticmethod
-    def _create_or_update(_reddit, allow_images=None, allow_top=None,
+    def _create_or_update(_reddit, allow_images=None,
+                          allow_post_crossposts=None, allow_top=None,
                           collapse_deleted_comments=None,
                           comment_score_hide_mins=None, description=None,
                           domain=None, exclude_banned_modqueue=None,
@@ -72,8 +104,9 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
                           suggested_comment_sort=None, title=None,
                           wiki_edit_age=None, wiki_edit_karma=None,
                           wikimode=None, **other_settings):
-        # pylint: disable=invalid-name,too-many-locals
+        # pylint: disable=invalid-name,too-many-locals,too-many-arguments
         model = {'allow_images': allow_images,
+                 'allow_post_crossposts': allow_post_crossposts,
                  'allow_top': allow_top,
                  'collapse_deleted_comments': collapse_deleted_comments,
                  'comment_score_hide_mins': comment_score_hide_mins,
@@ -141,11 +174,46 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
     @property
     def contributor(self):
-        """Provide an instance of :class:`.ContributorRelationship`."""
+        """Provide an instance of :class:`.ContributorRelationship`.
+
+        Contributors are also known as approved submitters.
+
+        To add a contributor try:
+
+        .. code-block:: python
+
+           reddit.subreddit('SUBREDDIT').contributor.add('NAME')
+
+        """
         if self._contributor is None:
             self._contributor = ContributorRelationship(self, 'contributor')
         return self._contributor
 
+    @property
+    def emoji(self):
+        """Provide an instance of :class:`.SubredditEmoji`.
+
+        This attribute can be used to discover all emoji for a subreddit:
+
+        .. code:: python
+
+           for emoji in reddit.subreddit('iama').emoji:
+               print(emoji)
+
+        A single emoji can be lazily retrieved via:
+
+        .. code:: python
+
+           reddit.subreddit('blah').emoji['emoji_name']
+
+        .. note:: Attempting to access attributes of an nonexistent emoji will
+           result in a :class:`.ClientException`.
+
+        """
+        if self._emoji is None:
+            self._emoji = SubredditEmoji(self)
+        return self._emoji
+
     @property
     def filters(self):
         """Provide an instance of :class:`.SubredditFilters`."""
@@ -267,6 +335,30 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
             self._stylesheet = SubredditStylesheet(self)
         return self._stylesheet
 
+    @property
+    def widgets(self):
+        """Provide an instance of :class:`.SubredditWidgets`.
+
+        **Example usage**
+
+        Get all sidebar widgets:
+
+        .. code-block:: python
+
+           for widget in reddit.subreddit('redditdev').widgets.sidebar:
+               print(widget)
+
+        Get ID card widget:
+
+        .. code-block:: python
+
+           print(reddit.subreddit('redditdev').widgets.id_card)
+
+        """
+        if self._widgets is None:
+            self._widgets = SubredditWidgets(self)
+        return self._widgets
+
     @property
     def wiki(self):
         """Provide an instance of :class:`.SubredditWiki`.
@@ -307,6 +399,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
         if display_name:
             self.display_name = display_name
         self._banned = self._contributor = self._filters = self._flair = None
+        self._emoji = self._widgets = None
         self._mod = self._moderator = self._modmail = self._muted = None
         self._quarantine = self._stream = self._stylesheet = self._wiki = None
         self._path = API_PATH['subreddit'].format(subreddit=self)
@@ -384,65 +477,6 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
         return self._submission_class(self._reddit, url=urljoin(
             self._reddit.config.reddit_url, path))
 
-    def submissions(self, start=None, end=None, extra_query=None):
-        """Yield submissions created between timestamps ``start`` and ``end``.
-
-        :param start: A UNIX timestamp indicating the earliest creation time of
-            submission yielded during the call. A value of ``None`` will
-            consider all submissions older than ``end`` (default: None).
-        :param end: A UNIX timestamp indicating the latest creation time of a
-            submission yielded during the call. A value of ``None`` will
-            consider all submissions newer than ``start`` (default: None).
-        :param extra_query: A cloudsearch query that will be combined via
-            ``(and timestamp:start..end EXTRA_QUERY)`` to further filter
-            results (default: None).
-
-        Submissions are yielded newest first.
-
-        **Example**: Suppose you want to obtain all submissions to
-        ``/r/politics`` on November 8, 2016 PST. First, you need to determine
-        the start and end dates as UNIX timestamps. Using
-        http://www.epochconverter.com/, those timestamps are 1478592000 and
-        1478678400, respectively. The following outputs all such submissions'
-        titles:
-
-        .. code:: python
-
-           subreddit = reddit.subreddit('politics')
-           for submission in subreddit.submissions(1478592000, 1478678400):
-               print(submission.title)
-
-        As of this writing there are 809 results.
-
-        .. note:: The results are only as reliable as reddit's search.
-           Submissions may be missing from the results.
-
-        """
-        utc_offset = 28800
-        now = int(time.time())
-        start = max(int(start) + utc_offset if start else 0, 0)
-        end = min(int(end) if end else now, now) + utc_offset
-
-        found_new_submission = True
-        last_ids = set()
-        params = {}
-        while found_new_submission:
-            query = 'timestamp:{}..{}'.format(start, end)
-            if extra_query:
-                query = '(and {} {})'.format(query, extra_query)
-
-            current_ids = set()
-            found_new_submission = False
-            for submission in self.search(query, limit=None, params=params,
-                                          sort='new', syntax='cloudsearch'):
-                current_ids.add(submission.id)
-                end = min(end, int(submission.created))
-                if submission.id not in last_ids:
-                    found_new_submission = True
-                yield submission
-                params['after'] = submission.fullname
-            last_ids = current_ids
-
     def submit(self, title, selftext=None, url=None, flair_id=None,
                flair_text=None, resubmit=True, send_replies=True):
         """Add a submission to the subreddit.
@@ -584,7 +618,7 @@ class SubredditFilters(object):
             special=self.subreddit, user=self.subreddit._reddit.user.me(),
             subreddit=subreddit)
         self.subreddit._reddit.request(
-            'PUT', url, data={'model': dumps({'name': subreddit})})
+            'PUT', url, data={'model': dumps({'name': str(subreddit)})})
 
     def remove(self, subreddit):
         """Remove ``subreddit`` from the list of filtered subreddits.
@@ -596,7 +630,7 @@ class SubredditFilters(object):
         """
         url = API_PATH['subreddit_filter'].format(
             special=self.subreddit, user=self.subreddit._reddit.user.me(),
-            subreddit=subreddit)
+            subreddit=str(subreddit))
         self.subreddit._reddit.request('DELETE', url, data={})
 
 
@@ -1169,6 +1203,8 @@ class SubredditModeration(object):
 
         :param allow_images: Allow users to upload images using the native
             image hosting. Only applies to link-only subreddits.
+        :param allow_post_crossposts: Allow users to crosspost submissions from
+            other subreddits.
         :param allow_top: Allow the subreddit to appear on ``/r/all`` as well
             as the default and trending lists.
         :param collapse_deleted_comments: Collapse deleted and removed comments
@@ -1376,6 +1412,8 @@ class SubredditRelationship(object):
 class ContributorRelationship(SubredditRelationship):
     """Provides methods to interact with a Subreddit's contributors.
 
+    Contributors are also known as approved submitters.
+
     Contributors of a subreddit can be iterated through like so:
 
     .. code-block:: python
@@ -1468,6 +1506,7 @@ class ModeratorRelationship(SubredditRelationship):
         """
         other_settings = self._handle_permissions(permissions, other_settings)
         super(ModeratorRelationship, self).add(redditor, **other_settings)
+
     # pylint: enable=arguments-differ
 
     def invite(self, redditor, permissions=None, **other_settings):
@@ -1578,7 +1617,7 @@ class ModeratorRelationship(SubredditRelationship):
 class Modmail(object):
     """Provides modmail functions for a subreddit."""
 
-    def __call__(self, id=None, mark_read=False):
+    def __call__(self, id=None, mark_read=False):  # noqa: D207, D301
         """Return an individual conversation.
 
         :param id: A reddit base36 conversation ID, e.g., ``2gmz``.
@@ -1595,8 +1634,8 @@ class Modmail(object):
 
         .. code:: python
 
-           conversation = reddit.subreddit('redditdev').modmail('2gmz',
-                                                                mark_read=True)
+           conversation = reddit.subreddit('redditdev').modmail('2gmz', \
+mark_read=True)
            for message in conversation.messages:
                print(message.body_markdown)
 
@@ -1610,16 +1649,16 @@ class Modmail(object):
 
         .. code:: python
 
-           conversation = reddit.subreddit('redditdev').modmail('2gmz',
-                                                                mark_read=True)
+           conversation = reddit.subreddit('redditdev').modmail('2gmz', \
+mark_read=True)
            print(conversation.user.ban_status)
 
         To print a list of recent submissions by the user:
 
         .. code:: python
 
-           conversation = reddit.subreddit('redditdev').modmail('2gmz',
-                                                                mark_read=True)
+           conversation = reddit.subreddit('redditdev').modmail('2gmz', \
+mark_read=True)
            print(conversation.user.recent_posts)
 
         """
@@ -1668,7 +1707,7 @@ class Modmail(object):
                 for conversation_id in response['conversation_ids']]
 
     def conversations(self, after=None, limit=None, other_subreddits=None,
-                      sort=None, state=None):
+                      sort=None, state=None):  # noqa: D207, D301
         """Generate :class:`.ModmailConversation` objects for subreddit(s).
 
         :param after: A base36 modmail conversation id. When provided, the
@@ -1689,7 +1728,8 @@ class Modmail(object):
 
         .. code:: python
 
-            conversations = reddit.subreddit('all').conversations(state='mod')
+            conversations = reddit.subreddit('all').modmail.conversations(\
+state='mod')
 
         """
         params = {}
@@ -1791,7 +1831,7 @@ class SubredditStream(object):
         Comments are yielded oldest first. Up to 100 historical comments will
         initially be returned.
 
-        Keyword arguments are passed to :meth:`.stream_generator`.
+        Keyword arguments are passed to :func:`.stream_generator`.
 
         For example, to retrieve all new comments made to the ``iama``
         subreddit, try:
@@ -1810,7 +1850,7 @@ class SubredditStream(object):
         Submissions are yielded oldest first. Up to 100 historical submissions
         will initially be returned.
 
-        Keyword arguments are passed to :meth:`.stream_generator`.
+        Keyword arguments are passed to :func:`.stream_generator`.
 
         For example to retrieve all new submissions made to all of Reddit, try:
 
