@@ -76,7 +76,7 @@ def permissions_string(permissions, known_permissions):
     return ','.join(to_set)
 
 
-def stream_generator(function, pause_after=None):
+def stream_generator(function, pause_after=None, skip_existing=False):
     """Yield new items from ListingGenerators and ``None`` when paused.
 
     :param function: A callable that returns a ListingGenerator, e.g.
@@ -90,13 +90,25 @@ def stream_generator(function, pause_after=None):
         ``0`` yields ``None`` after every response resulting in no new items,
         and a value of ``None`` never introduces a pause (default: None).
 
+    :param skip_existing: When True does not yield any results from the first
+        request thereby skipping any items that existed in the stream prior to
+        starting the stream (default: False).
+
     .. note:: This function internally uses an exponential delay with jitter
        between subsequent responses that contain no new results, up to a
        maximum delay of just over a 16 seconds. In practice that means that the
        time before pause for ``pause_after=N+1`` is approximately twice the
        time before pause for ``pause_after=N``.
 
-    For example to pause a comment stream after six responses with no new
+    For example, to create a stream of comment replies, try:
+
+    .. code:: python
+
+       reply_function = reddit.inbox.comment_replies
+       for reply in praw.models.util.stream_generator(reply_function):
+           print(reply)
+
+    To pause a comment stream after six responses with no new
     comments, try:
 
     .. code:: python
@@ -125,7 +137,7 @@ def stream_generator(function, pause_after=None):
            print(comment)
 
     To bypass the internal exponential backoff, try the following. This
-    approach is useful if you are monitoring an subreddit with infrequent
+    approach is useful if you are monitoring a subreddit with infrequent
     activity, and you want the to consistently learn about new items from the
     stream as soon as possible, rather than up to a delay of just over sixteen
     seconds.
@@ -159,8 +171,10 @@ def stream_generator(function, pause_after=None):
             found = True
             seen_fullnames.add(item.fullname)
             newest_fullname = item.fullname
-            yield item
+            if not skip_existing:
+                yield item
         before_fullname = newest_fullname
+        skip_existing = False
         if valid_pause_after and pause_after < 0:
             yield None
         elif found:
@@ -169,6 +183,7 @@ def stream_generator(function, pause_after=None):
         else:
             responses_without_new += 1
             if valid_pause_after and responses_without_new > pause_after:
+                exponential_counter.reset()
                 responses_without_new = 0
                 yield None
             else:
